@@ -10,6 +10,7 @@ from typing import Optional, Sequence, Tuple
 
 import numpy as np
 import numpy.typing as npt
+from matplotlib.axes import Axes
 from monty.json import MSONable
 from pymatgen.electronic_structure.core import Spin
 from pymatgen.io.vasp.optics import DielectricFunctionCalculator
@@ -66,7 +67,7 @@ class HarmonicDefect(MSONable):
     defect_band: Optional[Sequence[tuple]] = None
     relaxed_index: Optional[int] = None
     relaxed_bandstructure: Optional[BandStructure] = None
-    wswqs: Optional[dict[float, WSWQ]] = None
+    wswqs: Optional[list[dict]] = None
     waveder: Optional[Waveder] = None
 
     def __repr__(self) -> str:
@@ -326,9 +327,11 @@ class HarmonicDefect(MSONable):
             raise ValueError(
                 f"Number of WSWQ files ({len(wswq_files)}) does not match number of distortions ({len(distortions)})."
             )
-        self.wswqs = {d: WSWQ.from_file(f) for d, f in zip(distortions, wswq_files)}
+        self.wswqs = [
+            {"Q": d, "wswq": WSWQ.from_file(f)} for d, f in zip(distortions, wswq_files)
+        ]
 
-    def get_elph_me(self, defect_state: tuple[int, int, int]) -> npt.ArrayLike:
+    def get_elph_me(self, defect_state: tuple) -> npt.ArrayLike:
         """Calculate the electron phonon matrix elements.
 
         Combine the data from the WSWQs to calculate the electron phonon matrix elements.
@@ -350,8 +353,8 @@ class HarmonicDefect(MSONable):
         """
         if self.wswqs is None:
             raise RuntimeError("WSWQs have not been read. Use `read_wswqs` first.")
-        distortions = list(self.wswqs.keys())
-        wswqs = list(self.wswqs.values())
+        distortions = [wswq["Q"] for wswq in self.wswqs]
+        wswqs = [wswq["wswq"] for wswq in self.wswqs]
         band_index, kpoint_index, spin_index = defect_state
         # The second band index is associated with the defect state
         # since we are usually interested in capture
@@ -378,10 +381,6 @@ class HarmonicDefect(MSONable):
             The eigenvalue difference to the defect band in the order specified by output_order.
 
         """
-        if self.defect_band_index is None:
-            raise ValueError(  # pragma: no cover
-                "The ``defect_band_index`` must be set before ``ediff`` can be computed."
-            )
         if self.relaxed_bandstructure is None:
             raise ValueError(  # pragma: no cover
                 "The ``relaxed_bandstructure`` must be set before ``ediff`` can be computed. "
@@ -390,7 +389,7 @@ class HarmonicDefect(MSONable):
 
         ediffs_ = _get_ks_ediff(
             bandstructure=self.relaxed_bandstructure,
-            defect_band_index=self.defect_band_index,
+            defect_band=self.defect_band,
         )
         ediffs_stack = [
             ediffs_[Spin.up].T,
@@ -483,6 +482,7 @@ def get_SRH_coefficient(
     g: int = 1,
     occ_tol: float = 1e-3,
     n_band_edge: int = 1,
+    use_final_state_elph: bool = False,
 ) -> npt.ArrayLike:
     """Get the SRH coefficient for a defect.
 
@@ -495,12 +495,18 @@ def get_SRH_coefficient(
         g: The degeneracy of the defect state.
         occ_tol: The tolerance for determining if a state is occupied.
         n_band_edge: The number of bands to average over at the band edge.
+        use_final_state_elph: Whether to use the final state's ELPH data.
+            This is useful if the initial state does not have a well-defined
+            defect state.
 
     Returns:
         The SRH recombination coefficient in units of cm^3 s^-1.
     """
-    me_all = initial_state.get_elph_me(defect_state=defect_state)
-    defect_band, defect_kpt, defect_spin = defect_state
+    if use_final_state_elph:
+        me_all = final_state.get_elph_me(defect_state=defect_state)
+    else:
+        me_all = initial_state.get_elph_me(defect_state=defect_state)
+    defect_band, _, _ = defect_state
 
     if initial_state.charge_state == final_state.charge_state + 1:
         band_slice = slice(defect_band + 1, defect_band + 1 + n_band_edge)
@@ -735,7 +741,7 @@ def _get_wswq_slope(distortions: list[float], wswqs: list[WSWQ]) -> npt.NDArray:
 
 def _get_ks_ediff(
     bandstructure: BandStructure,
-    defect_band_index: int,
+    defect_band: Sequence[tuple],
 ) -> dict[Spin, npt.NDArray]:
     """Calculate the Kohn-Sham energy between the defect state.
 
@@ -744,15 +750,53 @@ def _get_ks_ediff(
 
     Args:
         bandstructure: A BandStructure object.
-        defect_band_index: The index of the defect band.
+        defect_band: The defect band given as a list of tuples (band_index, kpoint_index, spin_index).
 
     Returns:
         npt.NDArray: The Kohn-Sham energy difference between the defect state and other states.
         Indexed the same way as ``bandstructure.bands``.
     """
     res = dict()
-    for k, kpt_bands in bandstructure.bands.items():
-        e_at_def_band = kpt_bands[defect_band_index, :]
-        e_diff = kpt_bands - e_at_def_band
-        res[k] = e_diff
+    b_at_kpt_and_spin = {(k, s): b for b, k, s in defect_band}
+    for ispin, eigs in bandstructure.bands.items():
+        spin_index = 0 if ispin == Spin.up else 1
+        res[ispin] = np.zeros_like(eigs)
+        for ikpt, kpt in enumerate(bandstructure.kpoints):
+            iband = b_at_kpt_and_spin.get((ikpt, spin_index), None)
+            # import ipdb; ipdb.set_trace()
+            if iband is None:
+                continue
+            e_at_def_band = eigs[iband, ikpt]
+            e_diff = eigs[:, ikpt] - e_at_def_band
+            res[ispin][:, ikpt] = e_diff
     return res
+
+
+def plot_pes(
+    hd: HarmonicDefect, x_shift=0, y_shift=0, width: float = 1.0, ax: Axes = None
+) -> None:
+    """Plot the Potential Energy Surface of a HarmonicDefect.
+
+    Args:
+        hd: HarmonicDefect object
+        x_shift: shift the PES by this amount in the x-direction
+        y_shift: shift the PES by this amount in the y-direction
+
+    Returns:
+        None
+    """
+    if ax is None:
+        from matplotlib import pyplot as plt
+
+        fig, ax = plt.subplots()
+    ax.plot(
+        np.array(hd.distortions) + x_shift,
+        (np.array(hd.energies) - hd.energies[hd.relaxed_index]) + y_shift,
+        "o",
+        ms=10,
+    )
+    xx = np.linspace(-width / 2, width / 2, 20)
+    yy = 0.5 * hd.omega**2 * xx**2
+    ax.plot(xx + x_shift, (yy + y_shift))
+    ax.set_xlabel("Q [amu$^{1/2}$Å]")
+    ax.set_ylabel("Energy [eV]")
